@@ -29,8 +29,6 @@ class Sequential:
         self.i          = 0
         self.numTrain   = 0
         self.history    = None
-        self.cwd        = "LowPy " + str(datetime.now().strftime("%Y-%m-%d %H:%M:%S"))
-        os.mkdir(self.cwd)
 
     # Function for appending layer objects to the model
     def add(self,newLayer):
@@ -91,6 +89,10 @@ class Sequential:
             for c in range(self.V):
                 print("{:<10}".format(self.layer[l].sigma.get()[c]),end="")
             print("")
+            print("        {:<10}".format("init_param"),end="")
+            for c in range(self.V):
+                print("{:<10}".format(self.layer[l].initialization_parameter[c]),end="")
+            print("")
         print("")
         print("---------------------------------------------------------------")
         self.architecture = {
@@ -100,30 +102,33 @@ class Sequential:
             "Weight Initialization":[],
             "Alpha":[],
             "Beta":[],
-            "Sigma":[]
+            "Sigma":[],
+            "Initialization Parameter":[]
         }
         for l in range(len(self.layer)):
             self.architecture["Layer"].append(l)
             self.architecture["Inputs"].append(self.layer[l].I)
             self.architecture["Outputs"].append(self.layer[l].J)
-            self.architecture["Weight Initialization"].append(self.layer[l].weight_initialization)
+            self.architecture["Weight Initialization"].append(self.layer[l].initialization_type)
             self.architecture["Alpha"].append(self.layer[l].alpha)
             self.architecture["Beta"].append(self.layer[l].beta)
             self.architecture["Sigma"].append(self.layer[l].sigma)
+            self.architecture["Initialization Parameter"].append(self.layer[l].initialization_parameter)
         self.architecture = pd.DataFrame(self.architecture)
-        self.architecture.to_csv(self.cwd + "/Architecture.csv",index=False)
+        self.architecture.to_csv("Architecture.csv",index=False)
 
 
     # Track model data
     class metrics:
-        def __init__(self, cwd):
+        def __init__(self):
             self.train          = self.trialData()
             self.test           = self.trialData()
-            self.metricsDir     = cwd
-            self.trainDir       = self.metricsDir + "/Train"
-            self.testDir        = self.metricsDir + "/Test"
-            os.mkdir(self.trainDir)
-            os.mkdir(self.testDir)
+            self.trainDir       = "Train"
+            self.testDir        = "Test"
+            if not os.path.exists(self.trainDir):
+                os.mkdir(self.trainDir)
+            if not os.path.exists(self.testDir):
+                os.mkdir(self.testDir)
             self.architecture   = pd.DataFrame()
         class trialData:
             def __init__(self):
@@ -181,7 +186,7 @@ class Sequential:
         self.numConverged = 0
         self.peakAccuracy = 0
         self.describe()
-        self.history = self.metrics(self.cwd)
+        self.history = self.metrics()
         for self.epoch in range(epochs):
             if (self.verbose):
                 print("Epoch " + str(self.epoch))
